/**
 * Main route
 *
 * @author Pierre Hubert
 */

import {
	AppBar,
	IconButton,
	List,
	ListItem,
	ListItemIcon,
	ListItemText,
	makeStyles,
	Paper,
	Toolbar,
	Typography,
} from "@material-ui/core";
import { Home, Person } from "@material-ui/icons";
import CloseSharpIcon from "@material-ui/icons/CloseSharp";
import React from "react";
import {
	BrowserRouter as Router,
	Route,
	Switch,
	useHistory,
	useRouteMatch,
} from "react-router-dom";
import { AccountHelper } from "../../helpers/AccountHelper";
import { AccountSettingsRoute } from "./AccountSettingsRoute";
import { HomeRoute } from "./HomeRoute";
import { NotFoundRoute } from "./NotFoundRoute";

const useStyles = makeStyles((theme) => ({
	root: {
		display: "flex",
	},
	toolbar: {
		paddingRight: 24, // keep right padding when drawer closed
	},
	toolbarIcon: {
		display: "flex",
		alignItems: "center",
		justifyContent: "flex-end",
		padding: "0 8px",
		...theme.mixins.toolbar,
	},
	appBar: {
		zIndex: theme.zIndex.drawer + 1,
		width: `100%`,
		color: "white",
	},
	menuButton: {
		marginRight: 36,
	},
	menuButtonHidden: {
		display: "none",
	},
	title: {
		flexGrow: 1,
	},
	appBarSpacer: theme.mixins.toolbar,
	content: {
		flexGrow: 1,
		height: "100vh",
		overflow: "auto",
	},
	container: {
		paddingTop: theme.spacing(4),
		paddingBottom: theme.spacing(4),
	},
	paper: {
		padding: theme.spacing(2),
		display: "flex",
		overflow: "auto",
		flexDirection: "column",
	},
	fixedHeight: {
		height: 240,
	},
}));

function Menu() {
	return (
		<div>
			<List component="nav" aria-label="main mailbox folders">
				<MainMenuItem title="Home" icon={<Home />} uri="/" />
				<MainMenuItem
					title="My account"
					icon={<Person />}
					uri={"/accounts/" + AccountHelper.currentAccount.id}
				/>
			</List>
		</div>
	);
}

function MainMenuItem(p: {
	title: string;
	icon: React.ReactNode;
	uri: string;
}) {
	const history = useHistory();
	const openMyAccount = () => history.push(p.uri);

	const selected =
		useRouteMatch({
			path: p.uri,
			exact: true,
		}) != null;

	return (
		<ListItem button onClick={openMyAccount} selected={selected}>
			<ListItemIcon>{p.icon}</ListItemIcon>
			<ListItemText primary={p.title} />
		</ListItem>
	);
}

export function MainRoute() {
	const classes = useStyles();

	const signOut = () => {
		AccountHelper.signOut();
	};

	return (
		<Router>
			<div
				style={{
					height: "100%",
					display: "flex",
					flexDirection: "column",
				}}
			>
				<Toolbar></Toolbar>

				<AppBar
					position="fixed"
					className={classes.appBar}
					color="primary"
				>
					<Toolbar className={classes.toolbar}>
						<Typography
							component="h1"
							variant="h6"
							color="inherit"
							noWrap
							className={classes.title}
						>
							Comunic Console
						</Typography>

						<Typography>
							{AccountHelper.currentAccount.name}
							<br />
							<small>{AccountHelper.currentAccount.email}</small>
						</Typography>

						<IconButton aria-label="Sign out" onClick={signOut}>
							<CloseSharpIcon />
						</IconButton>
					</Toolbar>
				</AppBar>
				<div
					style={{
						display: "flex",
						flex: "1",
						flexDirection: "row",
						width: "100%",
					}}
				>
					<Paper style={{ width: "200px" }}>
						<Menu></Menu>
					</Paper>

					<div style={{ flex: "1", padding: "50px" }}>
						<div
							style={{
								height: "100%",
								margin: "auto",
								maxWidth: "1280px",
							}}
						>
							<Switch>
								<Route exact path="/">
									<HomeRoute></HomeRoute>
								</Route>

								<Route path="/accounts/:id">
									<AccountSettingsRoute></AccountSettingsRoute>
								</Route>

								<Route path="*">
									<NotFoundRoute></NotFoundRoute>
								</Route>
							</Switch>
						</div>
					</div>
				</div>
			</div>
		</Router>
	);
}
